@@ -140,7 +140,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -156,29 +156,29 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_cloudwatch
-import aws_cdk.aws_events
-import aws_cdk.aws_logs
-import aws_cdk.aws_stepfunctions
-import constructs
+import aws_cdk.aws_cloudwatch as _aws_cdk_aws_cloudwatch_ceddda9d
+import aws_cdk.aws_events as _aws_cdk_aws_events_ceddda9d
+import aws_cdk.aws_logs as _aws_cdk_aws_logs_ceddda9d
+import aws_cdk.aws_stepfunctions as _aws_cdk_aws_stepfunctions_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class EventbridgeToStepfunctions(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-eventbridge-stepfunctions.EventbridgeToStepfunctions",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
-        state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
+        event_rule_props: typing.Union[_aws_cdk_aws_events_ceddda9d.RuleProps, typing.Dict[builtins.str, typing.Any]],
+        state_machine_props: typing.Union[_aws_cdk_aws_stepfunctions_ceddda9d.StateMachineProps, typing.Dict[builtins.str, typing.Any]],
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-        existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+        event_bus_props: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventBusProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_event_bus_interface: typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus] = None,
+        log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -194,19 +194,7 @@ class EventbridgeToStepfunctions(
         :summary: Constructs a new instance of the EventbridgeToStepfunctions class.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
-                state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
-                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__11fd8cf8c2aa86550aadcaf0eb827e799d64f4cb5b9b5a38849b89c0caa910dd)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = EventbridgeToStepfunctionsProps(
@@ -222,30 +210,30 @@ class EventbridgeToStepfunctions(
 
     @builtins.property
     @jsii.member(jsii_name="eventsRule")
-    def events_rule(self) -> aws_cdk.aws_events.Rule:
-        return typing.cast(aws_cdk.aws_events.Rule, jsii.get(self, "eventsRule"))
+    def events_rule(self) -> _aws_cdk_aws_events_ceddda9d.Rule:
+        return typing.cast(_aws_cdk_aws_events_ceddda9d.Rule, jsii.get(self, "eventsRule"))
 
     @builtins.property
     @jsii.member(jsii_name="stateMachine")
-    def state_machine(self) -> aws_cdk.aws_stepfunctions.StateMachine:
-        return typing.cast(aws_cdk.aws_stepfunctions.StateMachine, jsii.get(self, "stateMachine"))
+    def state_machine(self) -> _aws_cdk_aws_stepfunctions_ceddda9d.StateMachine:
+        return typing.cast(_aws_cdk_aws_stepfunctions_ceddda9d.StateMachine, jsii.get(self, "stateMachine"))
 
     @builtins.property
     @jsii.member(jsii_name="stateMachineLogGroup")
-    def state_machine_log_group(self) -> aws_cdk.aws_logs.ILogGroup:
-        return typing.cast(aws_cdk.aws_logs.ILogGroup, jsii.get(self, "stateMachineLogGroup"))
+    def state_machine_log_group(self) -> _aws_cdk_aws_logs_ceddda9d.ILogGroup:
+        return typing.cast(_aws_cdk_aws_logs_ceddda9d.ILogGroup, jsii.get(self, "stateMachineLogGroup"))
 
     @builtins.property
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
         self,
-    ) -> typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]]:
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]], jsii.get(self, "cloudwatchAlarms"))
+    ) -> typing.Optional[typing.List[_aws_cdk_aws_cloudwatch_ceddda9d.Alarm]]:
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_cloudwatch_ceddda9d.Alarm]], jsii.get(self, "cloudwatchAlarms"))
 
     @builtins.property
     @jsii.member(jsii_name="eventBus")
-    def event_bus(self) -> typing.Optional[aws_cdk.aws_events.IEventBus]:
-        return typing.cast(typing.Optional[aws_cdk.aws_events.IEventBus], jsii.get(self, "eventBus"))
+    def event_bus(self) -> typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus], jsii.get(self, "eventBus"))
 
 
 @jsii.data_type(
@@ -264,12 +252,12 @@ class EventbridgeToStepfunctionsProps:
     def __init__(
         self,
         *,
-        event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
-        state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
+        event_rule_props: typing.Union[_aws_cdk_aws_events_ceddda9d.RuleProps, typing.Dict[builtins.str, typing.Any]],
+        state_machine_props: typing.Union[_aws_cdk_aws_stepfunctions_ceddda9d.StateMachineProps, typing.Dict[builtins.str, typing.Any]],
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-        existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+        event_bus_props: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventBusProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_event_bus_interface: typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus] = None,
+        log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
@@ -282,32 +270,22 @@ class EventbridgeToStepfunctionsProps:
         :summary: The properties for the EventbridgeToStepfunctions Construct
         '''
         if isinstance(event_rule_props, dict):
-            event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
+            event_rule_props = _aws_cdk_aws_events_ceddda9d.RuleProps(**event_rule_props)
         if isinstance(state_machine_props, dict):
-            state_machine_props = aws_cdk.aws_stepfunctions.StateMachineProps(**state_machine_props)
+            state_machine_props = _aws_cdk_aws_stepfunctions_ceddda9d.StateMachineProps(**state_machine_props)
         if isinstance(event_bus_props, dict):
-            event_bus_props = aws_cdk.aws_events.EventBusProps(**event_bus_props)
+            event_bus_props = _aws_cdk_aws_events_ceddda9d.EventBusProps(**event_bus_props)
         if isinstance(log_group_props, dict):
-            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
+            log_group_props = _aws_cdk_aws_logs_ceddda9d.LogGroupProps(**log_group_props)
         if __debug__:
-            def stub(
-                *,
-                event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
-                state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
-                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__db9254281d961668e5283454dbaeefa487e00b7213373a3fd22fb4b8bc4b9fbd)
             check_type(argname="argument event_rule_props", value=event_rule_props, expected_type=type_hints["event_rule_props"])
             check_type(argname="argument state_machine_props", value=state_machine_props, expected_type=type_hints["state_machine_props"])
             check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
             check_type(argname="argument event_bus_props", value=event_bus_props, expected_type=type_hints["event_bus_props"])
             check_type(argname="argument existing_event_bus_interface", value=existing_event_bus_interface, expected_type=type_hints["existing_event_bus_interface"])
             check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "event_rule_props": event_rule_props,
             "state_machine_props": state_machine_props,
         }
@@ -321,24 +299,26 @@ class EventbridgeToStepfunctionsProps:
             self._values["log_group_props"] = log_group_props
 
     @builtins.property
-    def event_rule_props(self) -> aws_cdk.aws_events.RuleProps:
+    def event_rule_props(self) -> _aws_cdk_aws_events_ceddda9d.RuleProps:
         '''User provided eventRuleProps to override the defaults.
 
         :default: - None
         '''
         result = self._values.get("event_rule_props")
         assert result is not None, "Required property 'event_rule_props' is missing"
-        return typing.cast(aws_cdk.aws_events.RuleProps, result)
+        return typing.cast(_aws_cdk_aws_events_ceddda9d.RuleProps, result)
 
     @builtins.property
-    def state_machine_props(self) -> aws_cdk.aws_stepfunctions.StateMachineProps:
+    def state_machine_props(
+        self,
+    ) -> _aws_cdk_aws_stepfunctions_ceddda9d.StateMachineProps:
         '''User provided StateMachineProps to override the defaults.
 
         :default: - None
         '''
         result = self._values.get("state_machine_props")
         assert result is not None, "Required property 'state_machine_props' is missing"
-        return typing.cast(aws_cdk.aws_stepfunctions.StateMachineProps, result)
+        return typing.cast(_aws_cdk_aws_stepfunctions_ceddda9d.StateMachineProps, result)
 
     @builtins.property
     def create_cloud_watch_alarms(self) -> typing.Optional[builtins.bool]:
@@ -350,33 +330,37 @@ class EventbridgeToStepfunctionsProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def event_bus_props(self) -> typing.Optional[aws_cdk.aws_events.EventBusProps]:
+    def event_bus_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_events_ceddda9d.EventBusProps]:
         '''A new custom EventBus is created with provided props.
 
         :default: - None
         '''
         result = self._values.get("event_bus_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_events.EventBusProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_events_ceddda9d.EventBusProps], result)
 
     @builtins.property
     def existing_event_bus_interface(
         self,
-    ) -> typing.Optional[aws_cdk.aws_events.IEventBus]:
+    ) -> typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus]:
         '''Existing instance of a custom EventBus.
 
         :default: - None
         '''
         result = self._values.get("existing_event_bus_interface")
-        return typing.cast(typing.Optional[aws_cdk.aws_events.IEventBus], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus], result)
 
     @builtins.property
-    def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
+    def log_group_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_logs_ceddda9d.LogGroupProps]:
         '''User provided props to override the default props for the CloudWatchLogs LogGroup.
 
         :default: - Default props are used
         '''
         result = self._values.get("log_group_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_logs.LogGroupProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_logs_ceddda9d.LogGroupProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -396,3 +380,29 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__11fd8cf8c2aa86550aadcaf0eb827e799d64f4cb5b9b5a38849b89c0caa910dd(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    event_rule_props: typing.Union[_aws_cdk_aws_events_ceddda9d.RuleProps, typing.Dict[builtins.str, typing.Any]],
+    state_machine_props: typing.Union[_aws_cdk_aws_stepfunctions_ceddda9d.StateMachineProps, typing.Dict[builtins.str, typing.Any]],
+    create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+    event_bus_props: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventBusProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_event_bus_interface: typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus] = None,
+    log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__db9254281d961668e5283454dbaeefa487e00b7213373a3fd22fb4b8bc4b9fbd(
+    *,
+    event_rule_props: typing.Union[_aws_cdk_aws_events_ceddda9d.RuleProps, typing.Dict[builtins.str, typing.Any]],
+    state_machine_props: typing.Union[_aws_cdk_aws_stepfunctions_ceddda9d.StateMachineProps, typing.Dict[builtins.str, typing.Any]],
+    create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+    event_bus_props: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventBusProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_event_bus_interface: typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus] = None,
+    log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
